@@ -71,13 +71,13 @@ class PresenceEnabledRedisManager(socketio.RedisManager):
 class PresenceEnabledServer(socketio.Server):
     def enter_room(self, sid, room, namespace=None, skip_presence=False):
         namespace = namespace or '/'
-        self.logger.info('%s is entering room %s [%s]', sid, room, namespace)
+        self.logger.debug('%s is entering room %s [%s]', sid, room, namespace)
         self.manager.enter_room(sid, namespace, room, skip_presence)
 
 
 def create_app(redis_url='redis://', channel='socketio', secret=None, presence_session_id=None, token_max_age=None, debug=False):
     mgr = PresenceEnabledRedisManager(redis_url, channel=channel, presence_session_id=presence_session_id)
-    sio = PresenceEnabledServer(client_manager=mgr, async_mode='eventlet', logger=not debug, cors_allowed_origins='*') # client must be identified via url token so cors to * is not a big risk
+    sio = PresenceEnabledServer(client_manager=mgr, async_mode='eventlet', logger=debug, cors_allowed_origins='*') # client must be identified via url token so cors to * is not a big risk
     token_serializer = URLSafeTimedSerializer(secret)
     default_ns = '/'
 
@@ -159,16 +159,25 @@ def wsgi_app(environ, start_response):
     return _wsgi_app(environ, start_response)
 
 
-def run_server(port=8888, access_logs=False, reuse_addr=False, **kwargs):
+def run_server(port=8888, access_logs=False, reuse_addr=False, presence_session_id=None, **kwargs):
     logger.addHandler(logging.StreamHandler())
     debug = kwargs.get('debug', False)
     if debug:
         logger.setLevel(logging.DEBUG)
         logger.debug('Push server running in DEBUG')
+
+    cleanup_presence_keys = False
+    if not presence_session_id:
+        presence_session_id = str(uuid.uuid4()).split('-')[0]
+        logger.info('Generated random presence session id: %s' % presence_session_id)
+        cleanup_presence_keys = True
+
+    kwargs['presence_session_id'] = presence_session_id
     app = create_app(**kwargs)
     socket = eventlet.listen(('', port), reuse_addr=reuse_addr)
     wsgi.server(socket, app, debug=debug, log_output=debug or access_logs)
-    if not kwargs.get('presence_session_id'):
+
+    if cleanup_presence_keys:
         app.engineio_app.manager.cleanup_presence_keys()
 
 
