@@ -23,7 +23,7 @@ def html_attributes(attrs=None, **kwargs):
         if isinstance(v, bool):
             v = k if v else ""
         k = k.replace("_", "-")
-        html.append('%s="%s"' % (k, str(v).strip()))
+        html.append(u'%s="%s"' % (k, unicode(v).strip()))
     return Markup(" ".join(html))
 
 
@@ -45,4 +45,4 @@ def timeago(dt, **args):
 def plural(singular, plural, num):
     if num > 1:
         return plural
-    return singular
\ No newline at end of file
+    return singular
