@@ -45,9 +45,8 @@ class PasswordValidationFailedError(Exception):
         return self.reason
 
 
-def validate_password(user, password, flash_messages=True, raise_error=True, pwhash=None):
+def validate_password(user, password, flash_messages=True, raise_error=True):
     state = get_extension_state('frasco_users')
-    pwhash = hash_password(password) if not pwhash else pwhash
 
     if state.options['min_time_between_password_change'] and user.last_password_change_at and not user.must_reset_password_at_login:
         if (datetime.datetime.utcnow() - user.last_password_change_at).total_seconds() < state.options['min_time_between_password_change']:
@@ -89,7 +88,7 @@ def update_password(user, password, skip_validation=False, **kwargs):
     """
     state = get_extension_state('frasco_users')
     pwhash = hash_password(password)
-    if not skip_validation and not validate_password(user, password, pwhash=pwhash, **kwargs):
+    if not skip_validation and not validate_password(user, password, **kwargs):
         return False
     if state.options['prevent_password_reuse']:
         user.previous_passwords = [user.password] + (user.previous_passwords or [])
@@ -116,7 +115,7 @@ def send_reset_password_token(user):
     """
     from frasco.mail import send_mail
     token = generate_reset_password_token(user)
-    send_mail(user.email, "users/reset_password.txt", user=user, token=token, locale=getattr(user, 'locale', None))
+    send_mail(user.email, "users/reset_password", user=user, token=token, locale=getattr(user, 'locale', None))
     reset_password_sent.send(user=user, token=token)
     logger.info('Password reset token sent to user #%s' % user.id)
     return token
